@@ -1,6 +1,16 @@
 from invoke import run, task
 
 
+@task
+def clean():
+    run('cd docs && make clean')
+
+
+@task
+def docs():
+    run('cd docs && make html')
+
+
 @task
 def package():
     run('python setup.py sdist')
